==> spip_4.0.4.orig.tar.xz: plugins-dist/mots/lang/mots_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=hu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Fontos csoport :</b> Erősen tanácsoljuk, hogy kulcs szót válasszon abban a csoportban.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'a honlap adminisztrátorai',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'a szerzők',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'a nyilvános honlap látogatói, ha küldenek üzenetet a fórumba.',

	// I
	'icone_creation_groupe_mots' => 'Új szócsoport létrehozása',
	'icone_creation_mots_cles' => 'Új kulcsszó létrehozása',
	'icone_modif_groupe_mots' => 'A szócsoport módosítása',
	'icone_mots_cles' => 'Kulcsszavak',
	'icone_supprimer_groupe_mots' => 'A csoport törlése',
	'icone_voir_tous_mots_cles' => 'AZ összes kulcsszó nézete',
	'info_articles_lies_mot' => 'A kulcsszóhoz kötött cikkek',
	'info_changer_nom_groupe' => 'A csoport neve változtatása :',
	'info_creation_mots_cles' => 'Itt hozza létre és konfigurálja a honlap kulcsszavait',
	'info_dans_groupe' => 'A csoportban :',
	'info_delet_mots_cles' => 'Kérte, hogy törölve legyen a kulcsszó
<b>@titre_mot@</b> (@type_mot@). Mivel ez a kulcsszó ehhez kapcsolódik
<b>@texte_lie@</b>, meg kell erősíteni ezt a döntést :', # MODIF
	'info_groupe_important' => 'Fontos csoport',
	'info_mots_cles' => 'A kulcsszavak',
	'info_mots_cles_association' => 'A csoport kulcsszavait lehet hozzárendelni :',
	'info_oui_suppression_mot_cle' => 'igen, véglegesen akarom törölni ezt a kucsszót.',
	'info_question_mots_cles' => 'Kivánja-e használni a kulcsszavakat a honlapján ?',
	'info_qui_attribue_mot_cle' => 'A csoport szavait hozzárendelheti :',
	'info_retirer_mot' => 'A szó törlése',
	'info_retirer_mots' => 'Az összes szó törlése',
	'info_rubriques_liees_mot' => 'A kulcsszóhoz kötött rovatok',
	'info_selection_un_seul_mot_cle' => '<b>Csak egy kulcsszó</b> választható egyszerre abban a csoportban.', # MODIF
	'info_supprimer_mot' => 'a szó törlése',
	'info_titre_mot_cle' => 'Kulcsszó neve, vagy címe',
	'info_un_mot' => 'Egyszerre csak egy szó',
	'item_ajout_mots_cles' => 'Fórumokhoz kötött kulcsszavak hozzáadása engedélyezése',
	'item_non_ajout_mots_cles' => 'Kulcsszavak használatának tiltása a fórumokban',
	'item_non_utiliser_config_groupe_mots_cles' => 'Nem kell használni a kulcsszó csoportok bővitett konfigurálását',
	'item_non_utiliser_mots_cles' => 'Nem kell használni a kulcsszavakat',
	'item_utiliser_config_groupe_mots_cles' => 'A kulcsszó csoportok bővített konfigurálásának használata',
	'item_utiliser_mots_cles' => 'Kulcsszavak használata',

	// L
	'logo_mot_cle' => 'A KULCSSZÓ LOGOJA',

	// T
	'texte_config_groupe_mots_cles' => 'Kivánja-e aktiválni a kulcsszavak bővített konfigurálását,
  például jelezve azt, hogy egyetlen szó választahtó egy csoportban, vagy fontos egy csoport... ?', # MODIF
	'texte_mots_cles' => 'A kulcsszavak a cikkek közti tématikus linkek létrehozását teszik lehetővé
  a rovatokban lévő helyuktől függetlenül. Úgy lehet könnyíteni
  a böngészést a honlapon, vagy akár szépíteni a cikkek kinézetét a csontvázokban.',
	'texte_mots_cles_dans_forum' => 'Kivánja-e engedélyezni a látógatók által kijelölt kulcsszavak használatát a nyilvános honlap fórumaiban ? (Vigyázat : ez a lehetőség viszonylag bonyolult.)', # MODIF
	'texte_nouveau_mot' => 'Új szó',
	'titre_config_groupe_mots_cles' => 'A kulcsszavak csoportjainak konfigurálása',
	'titre_gauche_mots_edit' => 'SZÓ SZÁMA :',
	'titre_mots_cles_dans_forum' => 'Kulcsszavak a nyilvános honlap fórumaiban',
	'titre_mots_tous' => 'Kulcsszavak',
	'titre_nouveau_groupe' => 'Új csoport',
	'titre_page_mots_tous' => 'Kulcsszavak'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=hu
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Fontos csoport :</b> Erősen tanácsoljuk, hogy kulcs szót válasszon abban a csoportban.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'a honlap adminisztrátorai',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'a szerzők',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'a nyilvános honlap látogatói, ha küldenek üzenetet a fórumba.',

	// I
	'icone_creation_groupe_mots' => 'Új szócsoport létrehozása',
	'icone_creation_mots_cles' => 'Új kulcsszó létrehozása',
	'icone_modif_groupe_mots' => 'A szócsoport módosítása',
	'icone_mots_cles' => 'Kulcsszavak',
	'icone_supprimer_groupe_mots' => 'A csoport törlése',
	'icone_voir_tous_mots_cles' => 'AZ összes kulcsszó nézete',
	'info_articles_lies_mot' => 'A kulcsszóhoz kötött cikkek',
	'info_changer_nom_groupe' => 'A csoport neve változtatása :',
	'info_creation_mots_cles' => 'Itt hozza létre és konfigurálja a honlap kulcsszavait',
	'info_dans_groupe' => 'A csoportban :',
	'info_delet_mots_cles' => 'Kérte, hogy törölve legyen a kulcsszó
<b>@titre_mot@</b> (@type_mot@). Mivel ez a kulcsszó ehhez kapcsolódik
<b>@texte_lie@</b>, meg kell erősíteni ezt a döntést :', # MODIF
	'info_groupe_important' => 'Fontos csoport',
	'info_mots_cles' => 'A kulcsszavak',
	'info_mots_cles_association' => 'A csoport kulcsszavait lehet hozzárendelni :',
	'info_oui_suppression_mot_cle' => 'igen, véglegesen akarom törölni ezt a kucsszót.',
	'info_question_mots_cles' => 'Kivánja-e használni a kulcsszavakat a honlapján ?',
	'info_qui_attribue_mot_cle' => 'A csoport szavait hozzárendelheti :',
	'info_retirer_mot' => 'A szó törlése',
	'info_retirer_mots' => 'Az összes szó törlése',
	'info_rubriques_liees_mot' => 'A kulcsszóhoz kötött rovatok',
	'info_selection_un_seul_mot_cle' => '<b>Csak egy kulcsszó</b> választható egyszerre abban a csoportban.', # MODIF
	'info_supprimer_mot' => 'a szó törlése',
	'info_titre_mot_cle' => 'Kulcsszó neve, vagy címe',
	'info_un_mot' => 'Egyszerre csak egy szó',
	'item_ajout_mots_cles' => 'Fórumokhoz kötött kulcsszavak hozzáadása engedélyezése',
	'item_non_ajout_mots_cles' => 'Kulcsszavak használatának tiltása a fórumokban',
	'item_non_utiliser_config_groupe_mots_cles' => 'Nem kell használni a kulcsszó csoportok bővitett konfigurálását',
	'item_non_utiliser_mots_cles' => 'Nem kell használni a kulcsszavakat',
	'item_utiliser_config_groupe_mots_cles' => 'A kulcsszó csoportok bővített konfigurálásának használata',
	'item_utiliser_mots_cles' => 'Kulcsszavak használata',

	// L
	'logo_mot_cle' => 'A KULCSSZÓ LOGOJA',

	// T
	'texte_config_groupe_mots_cles' => 'Kivánja-e aktiválni a kulcsszavak bővített konfigurálását,
  például jelezve azt, hogy egyetlen szó választahtó egy csoportban, vagy fontos egy csoport... ?', # MODIF
	'texte_mots_cles' => 'A kulcsszavak a cikkek közti tématikus linkek létrehozását teszik lehetővé
  a rovatokban lévő helyuktől függetlenül. Úgy lehet könnyíteni
  a böngészést a honlapon, vagy akár szépíteni a cikkek kinézetét a csontvázokban.',
	'texte_mots_cles_dans_forum' => 'Kivánja-e engedélyezni a látógatók által kijelölt kulcsszavak használatát a nyilvános honlap fórumaiban ? (Vigyázat : ez a lehetőség viszonylag bonyolult.)', # MODIF
	'texte_nouveau_mot' => 'Új szó',
	'titre_config_groupe_mots_cles' => 'A kulcsszavak csoportjainak konfigurálása',
	'titre_gauche_mots_edit' => 'SZÓ SZÁMA :',
	'titre_mots_cles_dans_forum' => 'Kulcsszavak a nyilvános honlap fórumaiban',
	'titre_mots_tous' => 'Kulcsszavak',
	'titre_nouveau_groupe' => 'Új csoport',
	'titre_page_mots_tous' => 'Kulcsszavak',
];
